OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "Error" : "Fout",
    "New note" : "Nuwe nota",
    "Help" : "Hulp",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Daar is ongestoorde veranderinge. Indien die bladsy gesluit word sal alle veranderinge geskrap word!",
    "Insert image" : "Voer beeld in",
    "File extension for new notes" : "Lêeruitbreiding vir nuwe notas",
    "All notes" : "Alle notas",
    "Categories" : "Kategorieë",
    "Loading …" : "Laai …",
    "Today" : "Vandag",
    "Yesterday" : "Gister",
    "This week" : "Vandeesweek",
    "Rename" : "Hernoem",
    "Details" : "Besonderhede",
    "Delete note" : "Skrap nota",
    "Remove from favorites" : "Verwyder uit gunstelinge",
    "Add to favorites" : "Voeg by gunstelinge",
    "Use current version" : "Gebruik huidige weergawe",
    "Edit" : "Wysig",
    "Preview" : "Voorskou",
    "Category" : "Kategorie",
    "Uncategorized" : "Ongekategorieseer",
    "Saving failed!" : "Stoor het misluk!",
    "_%n word_::_%n words_" : ["%n woord","%n woorde"],
    "Tasks" : "Take"
},
"nplurals=2; plural=(n != 1);");
